/* xkeycaps, Copyright (c) 1991, 1992, 1993 Jamie Zawinski <jwz@netscape.com>
 *
 * This file describes the keycodes of the MIPS Magnum AT/US keyboard.
 * By Michael Elbel <me@pcs.com>
 */

static const KeyCode magat_codes [] = {

  /* Row 0 */
  126,
  13, 14, 12, 20,
  11, 19, 139, 18,
  9, 17, 128, 15,
  24, 134, 31,

  /* Row 2 */
  22, 30, 38, 46, 45, 54, 62, 69, 70, 78, 77, 86, 93, 110,
  63, 32, 39,
  127, 23, 132, 131,

  /* Row 3 */
  21, 29, 37, 44, 53, 52, 61, 68, 75, 76, 85, 92, 99, 101,
  64, 48, 56,
  116, 125, 133, 129,
  
  /* Row 4 */
  96, 36, 35, 43, 51, 60, 59, 67, 74, 83, 84, 90, 98,
  115, 123, 124,

  /* Row 5 */
  26, 34, 42, 41, 50, 58, 57, 66, 73, 81, 82, 97,
  33,
  113, 122, 130, 10,

  /* Row 6 */
  28,
  25, 49, 27,
  16,
  40, 55, 47,
  120, 121
};
